# mantle2
![Linux Test](https://github.com/leonardt/mantle2/workflows/Linux%20Test/badge.svg)
[![codecov](https://codecov.io/gh/leonardt/mantle2/branch/main/graph/badge.svg?token=ZJBQMUQVSR)](https://codecov.io/gh/leonardt/mantle2)
